@@ -426,9 +426,12 @@ class Base(Controller):
         ]
     )
     def s3(self):
-        from ..ext.aws_s3 import get_lastest_file
         if self.app.pargs.action == '-1':
-            get_lastest_file(self.app.pargs.target)
+            from ..ext.aws_s3 import get_lastest_file
+            print(get_lastest_file(self.app.pargs.target))
+        if self.app.pargs.action == 'ls':
+            from ..ext.aws_s3 import get_latest_bucket
+            get_latest_bucket(self.app.pargs.target)
 
     @ex(
         help='Operations on the SSH config',
