@@ -36,11 +36,15 @@ def get_sg(profile: str, sid: int, sg_name = None):
     target_sg_dict = list(filter(lambda x: x['GroupName']==sg_name, resp['SecurityGroups']))
     return target_sg_dict
 
-def check_if_aux(ip_permissions: list):
+def check_if_exists(ip_ranges: list, descriptions: list):
+    # for each description check if there is a description in the existing permissions with the same description
     try:
-        return 'Aux' in ip_permissions['IpRanges'][0]['Description']
+        # TODO: why is 'ip_ranges' not defined?
+        return any([ ip_ranges['Description']==d for d in descriptions ])
+        # *** NameError: name 'ip_ranges' is not defined
+        # return 'Aux' in ip_ranges['IpRanges'][0]['Description']
     except IndexError as e:
-        assert ip_permissions['IpRanges']==[]
+        assert ip_ranges['IpRanges']==[]
         return False
     except KeyError as e:
         return False
@@ -60,15 +64,7 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
     ec2_res = boto3.session.Session(profile_name=profile, region_name='eu-west-1').resource('ec2')
     sg_res = ec2_res.SecurityGroup(target_sg_dict['GroupId'])
 
-    # loop using description to only remove Aux and not e.g. NFS or Home
-    # old port-based solution
-    permissions_to_revoke = [ s for s in sg_res.ip_permissions if check_if_aux(s) ]
-
-    # Removes all relevant permissions from this group (originally as `jakub`)
-    if sg_res.ip_permissions!=[] and permissions_to_revoke!=[]:
-        print('No permissions to revoke. Skipping.')
-        sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
-
+    # determine what the new sg rules should be either default or custom
     if messages=='':
         print('Warning messages are empty. Skipping')
         descriptions = {
@@ -84,6 +80,25 @@ def update_sg_to_ip(sg_name='jakub', # ip='2.222.105.71/32',
         descriptions = { int(k.split(':')[0]):k.split(':')[1] for k in items } 
         ports = [ int(i.split(':')[0]) for i in items ] 
 
+    # TODO: better check for different types of ingress rules
+    # currently just for 1 port group
+    assert len(sg_res.ip_permissions)==1
+
+    # loop using description to only remove already existing and replace them later
+    # effectiely overwriting them
+    ip_ranges_to_revoke = [ s for s in sg_res.ip_permissions[0]['IpRanges'] if check_if_exists(s, list(descriptions.values())) ]
+    permissions_to_revoke = [{ 
+        **sg_res.ip_permissions[0],
+        'IpRanges': ip_ranges_to_revoke }]
+
+    # Removes all relevant permissions from this group (originally as `jakub`)
+    if sg_res.ip_permissions!=[] and permissions_to_revoke==[]:
+        print('No permissions to revoke. Skipping.')
+    else:
+        sg_res.revoke_ingress(IpPermissions=permissions_to_revoke)
+        print(f'Removed permissions {permissions_to_revoke}')
+
+    # assign new rules   
     ip_perms = [ {
         'IpProtocol': 'tcp',
         'FromPort': ports[i],
